@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,11 +54,100 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 
 
+/* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
+#line 1 "rcfile_y.y"
+
+/*
+ * rcfile_y.y -- Run control file parser for fetchmail
+ *
+ * For license terms, see the file COPYING in this directory.
+ */
+
+#include "config.h"
+#include <stdio.h>
+#include <sys/types.h>
+#include <sys/file.h>
+#if defined(HAVE_SYS_WAIT_H)
+#include <sys/wait.h>
+#endif
+#include <sys/stat.h>
+#include <errno.h>
+#if defined(STDC_HEADERS)
+#include <stdlib.h>
+#endif
+#if defined(HAVE_UNISTD_H)
+#include <unistd.h>
+#endif
+#include <string.h>
+
+#if defined(__CYGWIN__)
+#include <sys/cygwin.h>
+#endif /* __CYGWIN__ */
+
+#include "fetchmail.h"
+#include "i18n.h"
+  
+/* parser reads these */
+char *rcfile;			/* path name of rc file */
+struct query cmd_opts;		/* where to put command-line info */
+
+/* parser sets these */
+struct query *querylist;	/* head of server list (globally visible) */
+
+int yydebug;			/* in case we didn't generate with -- debug */
+
+static struct query current;	/* current server record */
+static int prc_errflag;
+static struct hostdata *leadentry;
+static flag trailer;
+
+static void record_current(void);
+static void user_reset(void);
+static void reset_server(const char *name, int skip);
+
+/* these should be of size PATH_MAX */
+char currentwd[1024] = "", rcfiledir[1024] = "";
+
+/* using Bison, this arranges that yydebug messages will show actual tokens */
+extern char * yytext;
+#define YYPRINT(fp, type, val)	fprintf(fp, " = \"%s\"", yytext)
+
+
+/* Line 189 of yacc.c  */
+#line 131 "rcfile_y.c"
+
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+
+/* Enabling verbose error messages.  */
+#ifdef YYERROR_VERBOSE
+# undef YYERROR_VERBOSE
+# define YYERROR_VERBOSE 1
+#else
+# define YYERROR_VERBOSE 0
+#endif
+
+/* Enabling the token table.  */
+#ifndef YYTOKEN_TABLE
+# define YYTOKEN_TABLE 0
+#endif
+
+
 /* Tokens.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
@@ -263,106 +351,33 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 1 "rcfile_y.y"
-
-/*
- * rcfile_y.y -- Run control file parser for fetchmail
- *
- * For license terms, see the file COPYING in this directory.
- */
-
-#include "config.h"
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/file.h>
-#if defined(HAVE_SYS_WAIT_H)
-#include <sys/wait.h>
-#endif
-#include <sys/stat.h>
-#include <errno.h>
-#if defined(STDC_HEADERS)
-#include <stdlib.h>
-#endif
-#if defined(HAVE_UNISTD_H)
-#include <unistd.h>
-#endif
-#include <string.h>
-
-#if defined(__CYGWIN__)
-#include <sys/cygwin.h>
-#endif /* __CYGWIN__ */
-
-#include "fetchmail.h"
-#include "i18n.h"
-  
-/* parser reads these */
-char *rcfile;			/* path name of rc file */
-struct query cmd_opts;		/* where to put command-line info */
-
-/* parser sets these */
-struct query *querylist;	/* head of server list (globally visible) */
-
-int yydebug;			/* in case we didn't generate with -- debug */
-
-static struct query current;	/* current server record */
-static int prc_errflag;
-static struct hostdata *leadentry;
-static flag trailer;
-
-static void record_current(void);
-static void user_reset(void);
-static void reset_server(const char *name, int skip);
-
-/* these should be of size PATH_MAX */
-char currentwd[1024] = "", rcfiledir[1024] = "";
-
-/* using Bison, this arranges that yydebug messages will show actual tokens */
-extern char * yytext;
-#define YYPRINT(fp, type, val)	fprintf(fp, " = \"%s\"", yytext)
-
-
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
-
-/* Enabling verbose error messages.  */
-#ifdef YYERROR_VERBOSE
-# undef YYERROR_VERBOSE
-# define YYERROR_VERBOSE 1
-#else
-# define YYERROR_VERBOSE 0
-#endif
-
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
-#endif
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 58 "rcfile_y.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 58 "rcfile_y.y"
+
   int proto;
   int number;
   char *sval;
-}
-/* Line 187 of yacc.c.  */
-#line 353 "rcfile_y.c"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 369 "rcfile_y.c"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 366 "rcfile_y.c"
+/* Line 264 of yacc.c  */
+#line 381 "rcfile_y.c"
 
 #ifdef short
 # undef short
@@ -437,14 +452,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -525,9 +540,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -561,12 +576,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -1186,17 +1201,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -1230,11 +1248,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1510,19 +1528,21 @@ yydestruct (yymsg, yytype, yyvaluep)
   switch (yytype)
     {
       case 64: /* "STRING" */
+
+/* Line 1000 of yacc.c  */
 #line 86 "rcfile_y.y"
 	{ free ((yyvaluep->sval)); };
-#line 1516 "rcfile_y.c"
+
+/* Line 1000 of yacc.c  */
+#line 1538 "rcfile_y.c"
 	break;
 
       default:
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1538,11 +1558,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1550,9 +1569,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1576,14 +1595,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1591,51 +1635,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1665,7 +1686,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1673,7 +1693,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1696,9 +1715,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1709,7 +1727,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1719,6 +1736,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1727,16 +1747,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1768,20 +1788,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1821,151 +1837,211 @@ yyreduce:
   switch (yyn)
     {
         case 8:
+
+/* Line 1455 of yacc.c  */
 #line 101 "rcfile_y.y"
     {run.logfile = prependdir ((yyvsp[(4) - (4)].sval), rcfiledir); free((yyvsp[(4) - (4)].sval));}
     break;
 
   case 9:
+
+/* Line 1455 of yacc.c  */
 #line 102 "rcfile_y.y"
     {run.idfile = prependdir ((yyvsp[(4) - (4)].sval), rcfiledir); free((yyvsp[(4) - (4)].sval));}
     break;
 
   case 10:
+
+/* Line 1455 of yacc.c  */
 #line 103 "rcfile_y.y"
     {run.pidfile = prependdir ((yyvsp[(4) - (4)].sval), rcfiledir); free((yyvsp[(4) - (4)].sval));}
     break;
 
   case 11:
+
+/* Line 1455 of yacc.c  */
 #line 104 "rcfile_y.y"
     {run.poll_interval = (yyvsp[(4) - (4)].number);}
     break;
 
   case 12:
+
+/* Line 1455 of yacc.c  */
 #line 105 "rcfile_y.y"
     {run.postmaster = (yyvsp[(4) - (4)].sval);}
     break;
 
   case 13:
+
+/* Line 1455 of yacc.c  */
 #line 106 "rcfile_y.y"
     {run.bouncemail = TRUE;}
     break;
 
   case 14:
+
+/* Line 1455 of yacc.c  */
 #line 107 "rcfile_y.y"
     {run.bouncemail = FALSE;}
     break;
 
   case 15:
+
+/* Line 1455 of yacc.c  */
 #line 108 "rcfile_y.y"
     {run.spambounce = TRUE;}
     break;
 
   case 16:
+
+/* Line 1455 of yacc.c  */
 #line 109 "rcfile_y.y"
     {run.spambounce = FALSE;}
     break;
 
   case 17:
+
+/* Line 1455 of yacc.c  */
 #line 110 "rcfile_y.y"
     {run.softbounce = TRUE;}
     break;
 
   case 18:
+
+/* Line 1455 of yacc.c  */
 #line 111 "rcfile_y.y"
     {run.softbounce = FALSE;}
     break;
 
   case 19:
+
+/* Line 1455 of yacc.c  */
 #line 112 "rcfile_y.y"
     {run.properties = (yyvsp[(4) - (4)].sval);}
     break;
 
   case 20:
+
+/* Line 1455 of yacc.c  */
 #line 113 "rcfile_y.y"
     {run.use_syslog = TRUE;}
     break;
 
   case 21:
+
+/* Line 1455 of yacc.c  */
 #line 114 "rcfile_y.y"
     {run.use_syslog = FALSE;}
     break;
 
   case 22:
+
+/* Line 1455 of yacc.c  */
 #line 115 "rcfile_y.y"
     {run.invisible = TRUE;}
     break;
 
   case 23:
+
+/* Line 1455 of yacc.c  */
 #line 116 "rcfile_y.y"
     {run.invisible = FALSE;}
     break;
 
   case 24:
+
+/* Line 1455 of yacc.c  */
 #line 117 "rcfile_y.y"
     {run.showdots = FLAG_TRUE;}
     break;
 
   case 25:
+
+/* Line 1455 of yacc.c  */
 #line 118 "rcfile_y.y"
     {run.showdots = FLAG_FALSE;}
     break;
 
   case 26:
+
+/* Line 1455 of yacc.c  */
 #line 126 "rcfile_y.y"
     {record_current();}
     break;
 
   case 28:
+
+/* Line 1455 of yacc.c  */
 #line 131 "rcfile_y.y"
     {yyerror(GT_("server option after user options"));}
     break;
 
   case 29:
+
+/* Line 1455 of yacc.c  */
 #line 134 "rcfile_y.y"
     {reset_server((yyvsp[(2) - (2)].sval), FALSE); free((yyvsp[(2) - (2)].sval));}
     break;
 
   case 30:
+
+/* Line 1455 of yacc.c  */
 #line 135 "rcfile_y.y"
     {reset_server((yyvsp[(2) - (2)].sval), TRUE);  free((yyvsp[(2) - (2)].sval));}
     break;
 
   case 31:
+
+/* Line 1455 of yacc.c  */
 #line 136 "rcfile_y.y"
     {reset_server("defaults", FALSE);}
     break;
 
   case 34:
+
+/* Line 1455 of yacc.c  */
 #line 143 "rcfile_y.y"
     {save_str(&current.server.akalist,(yyvsp[(1) - (1)].sval),0); free((yyvsp[(1) - (1)].sval));}
     break;
 
   case 35:
+
+/* Line 1455 of yacc.c  */
 #line 144 "rcfile_y.y"
     {save_str(&current.server.akalist,(yyvsp[(2) - (2)].sval),0); free((yyvsp[(2) - (2)].sval));}
     break;
 
   case 36:
+
+/* Line 1455 of yacc.c  */
 #line 147 "rcfile_y.y"
     {save_str(&current.server.localdomains,(yyvsp[(1) - (1)].sval),0); free((yyvsp[(1) - (1)].sval));}
     break;
 
   case 37:
+
+/* Line 1455 of yacc.c  */
 #line 148 "rcfile_y.y"
     {save_str(&current.server.localdomains,(yyvsp[(2) - (2)].sval),0); free((yyvsp[(2) - (2)].sval));}
     break;
 
   case 39:
+
+/* Line 1455 of yacc.c  */
 #line 152 "rcfile_y.y"
     {current.server.via = (yyvsp[(2) - (2)].sval);}
     break;
 
   case 41:
+
+/* Line 1455 of yacc.c  */
 #line 154 "rcfile_y.y"
     {current.server.protocol = (yyvsp[(2) - (2)].proto);}
     break;
 
   case 42:
+
+/* Line 1455 of yacc.c  */
 #line 155 "rcfile_y.y"
     {
 					    current.server.protocol = P_POP3;
@@ -1981,21 +2057,29 @@ yyreduce:
     break;
 
   case 43:
+
+/* Line 1455 of yacc.c  */
 #line 166 "rcfile_y.y"
     {current.server.principal = (yyvsp[(2) - (2)].sval);}
     break;
 
   case 44:
+
+/* Line 1455 of yacc.c  */
 #line 167 "rcfile_y.y"
     {current.server.esmtp_name = (yyvsp[(2) - (2)].sval);}
     break;
 
   case 45:
+
+/* Line 1455 of yacc.c  */
 #line 168 "rcfile_y.y"
     {current.server.esmtp_password = (yyvsp[(2) - (2)].sval);}
     break;
 
   case 46:
+
+/* Line 1455 of yacc.c  */
 #line 169 "rcfile_y.y"
     {
 #ifdef SDPS_ENABLE
@@ -2008,26 +2092,36 @@ yyreduce:
     break;
 
   case 47:
+
+/* Line 1455 of yacc.c  */
 #line 177 "rcfile_y.y"
     {current.server.uidl = FLAG_TRUE;}
     break;
 
   case 48:
+
+/* Line 1455 of yacc.c  */
 #line 178 "rcfile_y.y"
     {current.server.uidl  = FLAG_FALSE;}
     break;
 
   case 49:
+
+/* Line 1455 of yacc.c  */
 #line 179 "rcfile_y.y"
     {current.server.checkalias = FLAG_TRUE;}
     break;
 
   case 50:
+
+/* Line 1455 of yacc.c  */
 #line 180 "rcfile_y.y"
     {current.server.checkalias  = FLAG_FALSE;}
     break;
 
   case 51:
+
+/* Line 1455 of yacc.c  */
 #line 181 "rcfile_y.y"
     {
 					current.server.service = (yyvsp[(2) - (2)].sval);
@@ -2035,6 +2129,8 @@ yyreduce:
     break;
 
   case 52:
+
+/* Line 1455 of yacc.c  */
 #line 184 "rcfile_y.y"
     {
 					int port = (yyvsp[(2) - (2)].number);
@@ -2045,6 +2141,8 @@ yyreduce:
     break;
 
   case 53:
+
+/* Line 1455 of yacc.c  */
 #line 190 "rcfile_y.y"
     {
 					int port = (yyvsp[(2) - (2)].number);
@@ -2055,21 +2153,29 @@ yyreduce:
     break;
 
   case 54:
+
+/* Line 1455 of yacc.c  */
 #line 197 "rcfile_y.y"
     {current.server.interval = (yyvsp[(2) - (2)].number);}
     break;
 
   case 55:
+
+/* Line 1455 of yacc.c  */
 #line 199 "rcfile_y.y"
     {current.server.authenticate = (yyvsp[(2) - (2)].proto);}
     break;
 
   case 56:
+
+/* Line 1455 of yacc.c  */
 #line 201 "rcfile_y.y"
     {current.server.timeout = (yyvsp[(2) - (2)].number);}
     break;
 
   case 57:
+
+/* Line 1455 of yacc.c  */
 #line 203 "rcfile_y.y"
     {
 					    current.server.envelope = (yyvsp[(3) - (3)].sval);
@@ -2078,6 +2184,8 @@ yyreduce:
     break;
 
   case 58:
+
+/* Line 1455 of yacc.c  */
 #line 208 "rcfile_y.y"
     {
 					    current.server.envelope = (yyvsp[(2) - (2)].sval);
@@ -2086,11 +2194,15 @@ yyreduce:
     break;
 
   case 59:
+
+/* Line 1455 of yacc.c  */
 #line 213 "rcfile_y.y"
     {current.server.qvirtual = (yyvsp[(2) - (2)].sval);}
     break;
 
   case 60:
+
+/* Line 1455 of yacc.c  */
 #line 214 "rcfile_y.y"
     {
 #ifdef CAN_MONITOR
@@ -2103,6 +2215,8 @@ yyreduce:
     break;
 
   case 61:
+
+/* Line 1455 of yacc.c  */
 #line 222 "rcfile_y.y"
     {
 #ifdef CAN_MONITOR
@@ -2115,131 +2229,183 @@ yyreduce:
     break;
 
   case 62:
+
+/* Line 1455 of yacc.c  */
 #line 230 "rcfile_y.y"
     { current.server.plugin = (yyvsp[(2) - (2)].sval); }
     break;
 
   case 63:
+
+/* Line 1455 of yacc.c  */
 #line 231 "rcfile_y.y"
     { current.server.plugout = (yyvsp[(2) - (2)].sval); }
     break;
 
   case 64:
+
+/* Line 1455 of yacc.c  */
 #line 232 "rcfile_y.y"
     {current.server.dns = FLAG_TRUE;}
     break;
 
   case 65:
+
+/* Line 1455 of yacc.c  */
 #line 233 "rcfile_y.y"
     {current.server.dns = FLAG_FALSE;}
     break;
 
   case 66:
+
+/* Line 1455 of yacc.c  */
 #line 234 "rcfile_y.y"
     {current.server.envelope = STRING_DISABLED;}
     break;
 
   case 67:
+
+/* Line 1455 of yacc.c  */
 #line 235 "rcfile_y.y"
     {current.server.tracepolls = FLAG_TRUE;}
     break;
 
   case 68:
+
+/* Line 1455 of yacc.c  */
 #line 236 "rcfile_y.y"
     {current.server.tracepolls = FLAG_FALSE;}
     break;
 
   case 69:
+
+/* Line 1455 of yacc.c  */
 #line 237 "rcfile_y.y"
     {current.server.badheader = BHACCEPT;}
     break;
 
   case 70:
+
+/* Line 1455 of yacc.c  */
 #line 238 "rcfile_y.y"
     {current.server.badheader = BHREJECT;}
     break;
 
   case 71:
+
+/* Line 1455 of yacc.c  */
 #line 241 "rcfile_y.y"
     {record_current(); user_reset();}
     break;
 
   case 73:
+
+/* Line 1455 of yacc.c  */
 #line 245 "rcfile_y.y"
     {record_current(); user_reset();}
     break;
 
   case 74:
+
+/* Line 1455 of yacc.c  */
 #line 246 "rcfile_y.y"
     {record_current(); user_reset();}
     break;
 
   case 76:
+
+/* Line 1455 of yacc.c  */
 #line 252 "rcfile_y.y"
     {current.remotename = (yyvsp[(2) - (2)].sval);}
     break;
 
   case 78:
+
+/* Line 1455 of yacc.c  */
 #line 254 "rcfile_y.y"
     {current.remotename = (yyvsp[(2) - (3)].sval);}
     break;
 
   case 83:
+
+/* Line 1455 of yacc.c  */
 #line 265 "rcfile_y.y"
     {current.wildcard =  TRUE;}
     break;
 
   case 84:
+
+/* Line 1455 of yacc.c  */
 #line 266 "rcfile_y.y"
     {current.wildcard =  FALSE;}
     break;
 
   case 85:
+
+/* Line 1455 of yacc.c  */
 #line 267 "rcfile_y.y"
     {current.wildcard =  TRUE;}
     break;
 
   case 88:
+
+/* Line 1455 of yacc.c  */
 #line 274 "rcfile_y.y"
     {save_str_pair(&current.localnames, (yyvsp[(1) - (1)].sval), NULL); free((yyvsp[(1) - (1)].sval));}
     break;
 
   case 89:
+
+/* Line 1455 of yacc.c  */
 #line 275 "rcfile_y.y"
     {save_str_pair(&current.localnames, (yyvsp[(1) - (3)].sval), (yyvsp[(3) - (3)].sval)); free((yyvsp[(1) - (3)].sval)); free((yyvsp[(3) - (3)].sval));}
     break;
 
   case 90:
+
+/* Line 1455 of yacc.c  */
 #line 278 "rcfile_y.y"
     {save_str(&current.mailboxes,(yyvsp[(1) - (1)].sval),0); free((yyvsp[(1) - (1)].sval));}
     break;
 
   case 91:
+
+/* Line 1455 of yacc.c  */
 #line 279 "rcfile_y.y"
     {save_str(&current.mailboxes,(yyvsp[(2) - (2)].sval),0); free((yyvsp[(2) - (2)].sval));}
     break;
 
   case 92:
+
+/* Line 1455 of yacc.c  */
 #line 282 "rcfile_y.y"
     {save_str(&current.smtphunt, (yyvsp[(1) - (1)].sval),TRUE); free((yyvsp[(1) - (1)].sval));}
     break;
 
   case 93:
+
+/* Line 1455 of yacc.c  */
 #line 283 "rcfile_y.y"
     {save_str(&current.smtphunt, (yyvsp[(2) - (2)].sval),TRUE); free((yyvsp[(2) - (2)].sval));}
     break;
 
   case 94:
+
+/* Line 1455 of yacc.c  */
 #line 286 "rcfile_y.y"
     {save_str(&current.domainlist, (yyvsp[(1) - (1)].sval),TRUE); free((yyvsp[(1) - (1)].sval));}
     break;
 
   case 95:
+
+/* Line 1455 of yacc.c  */
 #line 287 "rcfile_y.y"
     {save_str(&current.domainlist, (yyvsp[(2) - (2)].sval),TRUE); free((yyvsp[(2) - (2)].sval));}
     break;
 
   case 96:
+
+/* Line 1455 of yacc.c  */
 #line 291 "rcfile_y.y"
     {
 			    struct idlist *id;
@@ -2249,6 +2415,8 @@ yyreduce:
     break;
 
   case 97:
+
+/* Line 1455 of yacc.c  */
 #line 297 "rcfile_y.y"
     {
 			    struct idlist *id;
@@ -2258,111 +2426,155 @@ yyreduce:
     break;
 
   case 102:
+
+/* Line 1455 of yacc.c  */
 #line 309 "rcfile_y.y"
     {current.remotename  = (yyvsp[(2) - (3)].sval);}
     break;
 
   case 103:
+
+/* Line 1455 of yacc.c  */
 #line 310 "rcfile_y.y"
     {current.password    = (yyvsp[(2) - (2)].sval);}
     break;
 
   case 107:
+
+/* Line 1455 of yacc.c  */
 #line 314 "rcfile_y.y"
     {current.smtpaddress = (yyvsp[(2) - (2)].sval);}
     break;
 
   case 108:
+
+/* Line 1455 of yacc.c  */
 #line 315 "rcfile_y.y"
     {current.smtpname =    (yyvsp[(2) - (2)].sval);}
     break;
 
   case 110:
+
+/* Line 1455 of yacc.c  */
 #line 317 "rcfile_y.y"
     {current.mda         = (yyvsp[(2) - (2)].sval);}
     break;
 
   case 111:
+
+/* Line 1455 of yacc.c  */
 #line 318 "rcfile_y.y"
     {current.bsmtp       = prependdir ((yyvsp[(2) - (2)].sval), rcfiledir); free((yyvsp[(2) - (2)].sval));}
     break;
 
   case 112:
+
+/* Line 1455 of yacc.c  */
 #line 319 "rcfile_y.y"
     {current.listener    = LMTP_MODE;}
     break;
 
   case 113:
+
+/* Line 1455 of yacc.c  */
 #line 320 "rcfile_y.y"
     {current.preconnect  = (yyvsp[(2) - (2)].sval);}
     break;
 
   case 114:
+
+/* Line 1455 of yacc.c  */
 #line 321 "rcfile_y.y"
     {current.postconnect = (yyvsp[(2) - (2)].sval);}
     break;
 
   case 115:
+
+/* Line 1455 of yacc.c  */
 #line 323 "rcfile_y.y"
     {current.keep        = FLAG_TRUE;}
     break;
 
   case 116:
+
+/* Line 1455 of yacc.c  */
 #line 324 "rcfile_y.y"
     {current.flush       = FLAG_TRUE;}
     break;
 
   case 117:
+
+/* Line 1455 of yacc.c  */
 #line 325 "rcfile_y.y"
     {current.limitflush  = FLAG_TRUE;}
     break;
 
   case 118:
+
+/* Line 1455 of yacc.c  */
 #line 326 "rcfile_y.y"
     {current.fetchall    = FLAG_TRUE;}
     break;
 
   case 119:
+
+/* Line 1455 of yacc.c  */
 #line 327 "rcfile_y.y"
     {current.rewrite     = FLAG_TRUE;}
     break;
 
   case 120:
+
+/* Line 1455 of yacc.c  */
 #line 328 "rcfile_y.y"
     {current.forcecr     = FLAG_TRUE;}
     break;
 
   case 121:
+
+/* Line 1455 of yacc.c  */
 #line 329 "rcfile_y.y"
     {current.stripcr     = FLAG_TRUE;}
     break;
 
   case 122:
+
+/* Line 1455 of yacc.c  */
 #line 330 "rcfile_y.y"
     {current.pass8bits   = FLAG_TRUE;}
     break;
 
   case 123:
+
+/* Line 1455 of yacc.c  */
 #line 331 "rcfile_y.y"
     {current.dropstatus  = FLAG_TRUE;}
     break;
 
   case 124:
+
+/* Line 1455 of yacc.c  */
 #line 332 "rcfile_y.y"
     {current.dropdelivered = FLAG_TRUE;}
     break;
 
   case 125:
+
+/* Line 1455 of yacc.c  */
 #line 333 "rcfile_y.y"
     {current.mimedecode  = FLAG_TRUE;}
     break;
 
   case 126:
+
+/* Line 1455 of yacc.c  */
 #line 334 "rcfile_y.y"
     {current.idle        = FLAG_TRUE;}
     break;
 
   case 127:
+
+/* Line 1455 of yacc.c  */
 #line 336 "rcfile_y.y"
     {
 #ifdef SSL_ENABLE
@@ -2374,153 +2586,212 @@ yyreduce:
     break;
 
   case 128:
+
+/* Line 1455 of yacc.c  */
 #line 343 "rcfile_y.y"
     {current.sslkey = prependdir ((yyvsp[(2) - (2)].sval), rcfiledir); free((yyvsp[(2) - (2)].sval));}
     break;
 
   case 129:
+
+/* Line 1455 of yacc.c  */
 #line 344 "rcfile_y.y"
     {current.sslcert = prependdir ((yyvsp[(2) - (2)].sval), rcfiledir); free((yyvsp[(2) - (2)].sval));}
     break;
 
   case 130:
+
+/* Line 1455 of yacc.c  */
 #line 345 "rcfile_y.y"
     {current.sslproto = (yyvsp[(2) - (2)].sval);}
     break;
 
   case 131:
+
+/* Line 1455 of yacc.c  */
 #line 346 "rcfile_y.y"
     {current.sslcertck = FLAG_TRUE;}
     break;
 
   case 132:
+
+/* Line 1455 of yacc.c  */
 #line 347 "rcfile_y.y"
     {current.sslcertfile = prependdir((yyvsp[(2) - (2)].sval), rcfiledir); free((yyvsp[(2) - (2)].sval));}
     break;
 
   case 133:
+
+/* Line 1455 of yacc.c  */
 #line 348 "rcfile_y.y"
     {current.sslcertpath = prependdir((yyvsp[(2) - (2)].sval), rcfiledir); free((yyvsp[(2) - (2)].sval));}
     break;
 
   case 134:
+
+/* Line 1455 of yacc.c  */
 #line 349 "rcfile_y.y"
     {current.sslcommonname = (yyvsp[(2) - (2)].sval);}
     break;
 
   case 135:
+
+/* Line 1455 of yacc.c  */
 #line 350 "rcfile_y.y"
     {current.sslfingerprint = (yyvsp[(2) - (2)].sval);}
     break;
 
   case 136:
+
+/* Line 1455 of yacc.c  */
 #line 352 "rcfile_y.y"
     {current.keep        = FLAG_FALSE;}
     break;
 
   case 137:
+
+/* Line 1455 of yacc.c  */
 #line 353 "rcfile_y.y"
     {current.flush       = FLAG_FALSE;}
     break;
 
   case 138:
+
+/* Line 1455 of yacc.c  */
 #line 354 "rcfile_y.y"
     {current.limitflush  = FLAG_FALSE;}
     break;
 
   case 139:
+
+/* Line 1455 of yacc.c  */
 #line 355 "rcfile_y.y"
     {current.fetchall    = FLAG_FALSE;}
     break;
 
   case 140:
+
+/* Line 1455 of yacc.c  */
 #line 356 "rcfile_y.y"
     {current.rewrite     = FLAG_FALSE;}
     break;
 
   case 141:
+
+/* Line 1455 of yacc.c  */
 #line 357 "rcfile_y.y"
     {current.forcecr     = FLAG_FALSE;}
     break;
 
   case 142:
+
+/* Line 1455 of yacc.c  */
 #line 358 "rcfile_y.y"
     {current.stripcr     = FLAG_FALSE;}
     break;
 
   case 143:
+
+/* Line 1455 of yacc.c  */
 #line 359 "rcfile_y.y"
     {current.pass8bits   = FLAG_FALSE;}
     break;
 
   case 144:
+
+/* Line 1455 of yacc.c  */
 #line 360 "rcfile_y.y"
     {current.dropstatus  = FLAG_FALSE;}
     break;
 
   case 145:
+
+/* Line 1455 of yacc.c  */
 #line 361 "rcfile_y.y"
     {current.dropdelivered = FLAG_FALSE;}
     break;
 
   case 146:
+
+/* Line 1455 of yacc.c  */
 #line 362 "rcfile_y.y"
     {current.mimedecode  = FLAG_FALSE;}
     break;
 
   case 147:
+
+/* Line 1455 of yacc.c  */
 #line 363 "rcfile_y.y"
     {current.idle        = FLAG_FALSE;}
     break;
 
   case 148:
+
+/* Line 1455 of yacc.c  */
 #line 365 "rcfile_y.y"
     {current.use_ssl     = FLAG_FALSE;}
     break;
 
   case 149:
+
+/* Line 1455 of yacc.c  */
 #line 367 "rcfile_y.y"
     {current.limit       = NUM_VALUE_IN((yyvsp[(2) - (2)].number));}
     break;
 
   case 150:
+
+/* Line 1455 of yacc.c  */
 #line 368 "rcfile_y.y"
     {current.warnings    = NUM_VALUE_IN((yyvsp[(2) - (2)].number));}
     break;
 
   case 151:
+
+/* Line 1455 of yacc.c  */
 #line 369 "rcfile_y.y"
     {current.fetchlimit  = NUM_VALUE_IN((yyvsp[(2) - (2)].number));}
     break;
 
   case 152:
+
+/* Line 1455 of yacc.c  */
 #line 370 "rcfile_y.y"
     {current.fetchsizelimit = NUM_VALUE_IN((yyvsp[(2) - (2)].number));}
     break;
 
   case 153:
+
+/* Line 1455 of yacc.c  */
 #line 371 "rcfile_y.y"
     {current.fastuidl    = NUM_VALUE_IN((yyvsp[(2) - (2)].number));}
     break;
 
   case 154:
+
+/* Line 1455 of yacc.c  */
 #line 372 "rcfile_y.y"
     {current.batchlimit  = NUM_VALUE_IN((yyvsp[(2) - (2)].number));}
     break;
 
   case 155:
+
+/* Line 1455 of yacc.c  */
 #line 373 "rcfile_y.y"
     {current.expunge     = NUM_VALUE_IN((yyvsp[(2) - (2)].number));}
     break;
 
   case 156:
+
+/* Line 1455 of yacc.c  */
 #line 375 "rcfile_y.y"
     {current.properties  = (yyvsp[(2) - (2)].sval);}
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 2524 "rcfile_y.c"
+
+/* Line 1455 of yacc.c  */
+#line 2795 "rcfile_y.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2531,7 +2802,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -2596,7 +2866,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -2613,7 +2883,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -2670,9 +2940,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -2697,7 +2964,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2708,7 +2975,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -2734,6 +3001,8 @@ yyreturn:
 }
 
 
+
+/* Line 1675 of yacc.c  */
 #line 377 "rcfile_y.y"
 
 
