@@ -592,7 +592,7 @@ eoh:
 		    has_nuls = TRUE;
 		if (outlevel > O_SILENT)
 		    report(stdout,
-			   GT_("incorrect header line found while scanning headers\n"));
+			   GT_("incorrect header line found - see manpage for bad-header option\n"));
 		if (outlevel >= O_VERBOSE)
 		    report (stdout, GT_("line: %s"), line);
 		refuse_mail = 1;
@@ -1238,8 +1238,9 @@ process_headers:
 		    for (idp = msgblk.recipients; idp; idp = idp->next)
 			if (idp->val.status.mark == XMIT_ACCEPT)
 			    break;	/* only report first address */
-		    snprintf(buf+1, sizeof(buf)-1,
-			    "for <%s>", rcpt_address (ctl, idp->id, 1));
+		    if (idp)
+			snprintf(buf+1, sizeof(buf)-1,
+				"for <%s>", rcpt_address (ctl, idp->id, 1));
 		    snprintf(buf+strlen(buf), sizeof(buf)-strlen(buf)-1,
 			    " (%s); ",
 			    MULTIDROP(ctl) ? "multi-drop" : "single-drop");
